### dignified-python (v0.2.3)

**Purpose**: Version-aware Python coding standards with automatic version detection

**Artifacts**:

- skill: skills/dignified-python-310/SKILL.md, skills/dignified-python-311/SKILL.md, skills/dignified-python-312/SKILL.md, skills/dignified-python-313/SKILL.md
- doc: docs/dignified-python/dignified-python-core.md, docs/dignified-python/type-annotations-common.md, docs/dignified-python/version-specific/310/type-annotations.md, docs/dignified-python/version-specific/310/checklist.md, docs/dignified-python/version-specific/311/type-annotations.md, docs/dignified-python/version-specific/311/checklist.md, docs/dignified-python/version-specific/312/type-annotations.md, docs/dignified-python/version-specific/312/checklist.md, docs/dignified-python/version-specific/313/type-annotations-delta.md, docs/dignified-python/version-specific/313/checklist.md

**Usage**:

- Load `dignified-python-310` skill
